from setuptools import setup

with open("README.md", "r") as file:
    long_description = file.read()


setup(
    name="sv_ttk",
    version="2.3",
    license="MIT",
    author="rdbende",
    author_email="rdbende@gmail.com",
    url="https://github.com/rdbende/Sun-Valley-ttk-theme",
    project_urls={
        "Source": "https://github.com/rdbende/Sun-Valley-ttk-theme",
        "Documentation": "https://github.com/rdbende/Sun-Valley-ttk-theme/wiki",
        "Tracker": "https://github.com/rdbende/Sun-Valley-ttk-theme/issues",
    },
    description="A gorgeous theme for Tkinter, based on Windows 11's UI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["sv_ttk"],
    package_data={"sv_ttk": ["sv.tcl", "theme/*"]},
    python_requires=">=3.4",
    classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Software Development :: User Interfaces",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Tcl",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords=[
        "dark-theme",
        "modern",
        "sun-valley",
        "tcl",
        "tcl/tk",
        "theme",
        "theme",
        "tile",
        "tk",
        "tkinter",
        "ttk",
        "windows-11",
        "winui",
    ],
)



from functools import partial
from pathlib import Path

inited = False
root = None


def init_theme(func):
    def wrapper(*args, **kwargs):
        global inited
        global root

        if not inited:
            from tkinter import _default_root

            path = (Path(__file__).parent / "sv.tcl").resolve()

            try:
                _default_root.tk.call("source", str(path))
            except AttributeError:
                raise RuntimeError(
                    "can't set theme, because tkinter is not initialized. "
                    + "Please create a tkinter.Tk instance first and then set the theme."
                ) from None
            else:
                inited = True
                root = _default_root

        return func(*args, **kwargs)

    return wrapper


@init_theme
def set_theme(theme):
    if theme not in {"dark", "light"}:
        raise RuntimeError("not a valid theme name: {}".format(theme))

    root.tk.call("set_theme", theme)


@init_theme
def get_theme():
    theme = root.tk.call("ttk::style", "theme", "use")

    return {"sun-valley-dark": "dark", "sun-valley-light": "light"}.get(theme, theme)


@init_theme
def toggle_theme():
    if get_theme() == "light":
        use_dark_theme()
    else:
        use_light_theme()


use_dark_theme = partial(set_theme, "dark")
use_light_theme = partial(set_theme, "light")
